core.addons.CoreWindow - core

#

API Docs for: 0.0.2
Show: Inherited Protected Private Deprecated

# core.addons.CoreWindow Class

Extends core.Core
Defined in: `addons/core.window.js:10`
Module: addons

The main class that implements broadcaster pattern. Ideally subclassed by objects that will perform broadcasting functions.

## Constructor

### `core.addons.CoreWindow`

(

- `opts`

)

Defined in `addons/core.window.js:10`

#### Parameters:

- `opts` Object

  An object containing configurations required by the Core derived class.

  - `el` HTMLElement

    The node element included in the class composition.

- Index
- Methods
- Properties

## Item Index

### Methods

- clearProxyHandler
- construct
- delayedConstruct
- dispose
- find
- findAll
- getProxyHandler

### Properties

- node
- proxyHandlers

## Methods

### `clearProxyHandler`

(

- `method`

)

Inherited from core.Core: `src/core.js:716`

Core method for clearing proxied function methods.

#### Parameters:

- `method` String

  The string equivalent of the defined method to clear.

### `construct`

(

- `options`

)

Inherited from core.Core: `src/core.js:732`

Core method initialization. This is called automatically on core sub classes.

#### Parameters:

- `options` Object

  The object passed on the constructor of a core based class.

### `delayedConstruct`

(

- `options`

)

Inherited from core.Core: `src/core.js:740`

Core method initialization. This is called automatically on core sub classes. Adds delay when being called automatically, this allows time to setup all the other classes and manage the sequence of instantiations.

#### Parameters:

- `options` Object

  The object passed on the constructor of a core based class.

### `dispose`

(

- `removeNode`

)

Inherited from core.Core: `src/core.js:749`

Core method for destroying/cleaning up objects.

#### Parameters:

- `removeNode` Boolean

  If true and there is a node attached in the class (el property) that element is going to be removed upon disposal.

### `find`

(

- `selector`

)
NodeList

Inherited from core.Core: `src/core.js:770`

Core method for searching sub node elements.

#### Parameters:

- `selector` String

  The selector used for searching sub nodes.

#### Returns:

NodeList:

An array of HTMLElements, please note that this is not jQuery selected nodes.

### `findAll`

(

- `selector`

)
NodeList

Inherited from core.Core: `src/core.js:785`

Core method for searching sub node elements within the document context.

#### Parameters:

- `selector` String

  The selector used for searching sub nodes within the document.

#### Returns:

NodeList:

An array of HTMLElements, please note that this is not jQuery selected nodes.

### `getProxyHandler`

(

- `method`

)
Function

Inherited from core.Core: `src/core.js:695`

Returns a scope bound function and stores it on the proxyHandlers property.

#### Parameters:

- `method` String

  The string equivalent of the defined method name of the class.

#### Returns:

Function:

The scope bound function defined on the parameter.

## Properties

### `node`

HTMLElement

Inherited from core.Core: `src/core.js:641`

The selected HTML element node reference.

### `proxyHandlers`

Object

Inherited from core.Core: `src/core.js:658`

Property for storing proxied function/methods